@@ -11,13 +11,13 @@
 import GPS
 
 GPS.parse_xml ("""
-  <action name="Mark occurrences" >
+  <action name="Mark occurrences" category="Editor">
      <filter id="Source editor" />
      <description>Mark all the occurrences of the selected element in the current editor</description>
      <shell lang="python" >occurrences.mark_selected()</shell>
   </action>
 
-  <action name="Remove marked occurrences" >
+  <action name="Remove marked occurrences" category="Editor">
      <filter id="Source editor" />
      <description>Remove all highlightings done through Mark Occurrences</description>
      <shell lang="python" >occurrences.unmark_selected()</shell>
@@ -34,13 +34,15 @@ GPS.parse_xml ("""
 GPS.Editor.register_highlighting ("dynamic occurrences", "lightblue", True)
 
 def mark_selected ():
-   selection=GPS.Editor.get_chars (GPS.current_context().file().name())
+   buffer = GPS.EditorBuffer.get()
+   selection = buffer.get_chars (buffer.selection_start(), buffer.selection_end() - 1)
    context=GPS.current_context()
 
    if selection=="" and context.__class__ == GPS.EntityContext:
       selection=context.entity().name()
+
    if selection != "":
-      for m in context.file().search (selection):
+      for m in buffer.file().search (selection):
          GPS.Locations.add ("Local occurrences", m.file(), m.line(), m.column(),
               selection, highlight="dynamic occurrences", length=len(selection))
 
