@@ -9,7 +9,7 @@ public:
    int f () { return 0; }
 };
 
-static int A::my_static_int = 0;
+int A::my_static_int = 0;
 
 typedef A  My_Class;
 
@@ -26,8 +26,9 @@ BB ms;
 
 template <class T = int>
 class CCC {
+public:
    T t;
-   const int i;
+   int i;
    int& r;
 
    struct nested_struct {
@@ -47,7 +48,6 @@ int tf () { return n; }
 
 int main () {
    A a;
-   cc.fff();
    c.fff();
    tf<1> ();
    return a.f ();
