@@ -1,5 +1,5 @@
 class A {
-   int f ();
+public:
    int f () { ; }
    int g () { ; }
    int h ();
