@@ -64,7 +64,7 @@ class DocGenerator:
       pattern = re.compile (module_name + r'\.(\w+)(\.(\w+))?')
       here = 0
       result = []
-      linked_module = "<a href='" + self.filename_for_module (module_name) + "'>" + module_name + "</a>."
+      linked_module = "<a href='file://" + self.filename_for_module (module_name) + "'>" + module_name + "</a>."
 
       while True:
          match = pattern.search (text, here)
@@ -74,15 +74,15 @@ class DocGenerator:
 
          name1, foo, name2 = match.groups()
          if foo:
-            result.append (linked_module + "<a href='" + self.filename_for_class (name1) + "'>" + name1 \
-              + "</a>.<a href='" + self.filename_for_class (name1) + "#" + self.anchor_name (name2) + "'>" + name2 + "</a>")
+            result.append (linked_module + "<a href='file://" + self.filename_for_class (name1) + "'>" + name1 \
+              + "</a>.<a href='file://" + self.filename_for_class (name1) + "#" + self.anchor_name (name2) + "'>" + name2 + "</a>")
          else:
-            result.append (linked_module + "<a href='" + self.filename_for_class (name1) + "'>" + name1 + "</a>")
+            result.append (linked_module + "<a href='file://" + self.filename_for_class (name1) + "'>" + name1 + "</a>")
 
          here = end
       result.append (text[here:])
       return ''.join (result)
-                           
+
    def get_documentation (self, object):
       """Return the documentation for the object. This can easily be overriden if
          the documentation is dynamic for instance (a result of a method's call"""
@@ -318,7 +318,7 @@ class GPSDocGenerator (DocGenerator):
     """Class specifically setup to dynamically create the documentation for GPS's exported objects"""
 
     def __init__ (self, work_dir):
-        self.work_dir = work_dir 
+        self.work_dir = work_dir
         self.wrapper  = Help_Wrapper ()
 
     def get_documentation (self, object):
@@ -339,7 +339,9 @@ class GPSDocGenerator (DocGenerator):
         f.write (self.get_formated_documentation (module.__name__, "@hooks_list@"))
 
         f.write ("</table>")
-        for hook in GPS.Hook.list():
+        list = GPS.Hook.list()
+        list.sort()
+        for hook in list:
           f.write ("<table class='description'>\n")
           f.write ("  <caption>" + hook + "</caption>\n")
           f.write (self.get_formated_documentation (module.__name__, "@hook@ " + hook))
@@ -444,7 +446,7 @@ class Help_Wrapper:
          Help_Wrapper.current_class = ""
    set_current_class = staticmethod (set_current_class)
 
-   def getdoc_from_gps (self, object, as_html): 
+   def getdoc_from_gps (self, object, as_html):
       try:
 
          ## If we directly have a string, use it as the name to look up in the
@@ -530,7 +532,7 @@ pydoc.html          = XMLHtmlDoc()
 ## User accessible methods
 ####################################################################
 
-docgen = GPSDocGenerator (GPS.get_home_dir() + "/generated_doc")
+docgen = GPSDocGenerator (GPS.get_home_dir() + "generated_doc")
 
 def generate_doc (entity):
   """Generate the documentation for a python entity dynamically.
