@@ -1,6 +1,6 @@
 ## This file provides utilities used by the SPARK plug-in for GPS.
-## Copyright (c) 2004-2005 Praxis High Integrity Systems Limited
-## Copyright (c) 2005 AdaCore
+## Copyright (c) 2004-2006 Praxis High Integrity Systems Limited
+## Copyright (c) 2005-2006 AdaCore
 
 #####################################
 # SPARK Toolset Customization for GPS
@@ -49,6 +49,8 @@
 #
 ######################################
 
+
+
 a = """<?xml version="1.0"?>
 <!--  Note: do not use the ampersand character in XML comments!!       -->
 
@@ -135,43 +137,46 @@ a = """<?xml version="1.0"?>
   <tool name="Examiner">
     <language>SPARK</language>
     <language>Ada</language>
-    <switches lines="7">
-      <title line="1">Examiner Files</title>
+    <switches columns ="2" lines="5">
+      <title line="1" column-span="2">Examiner Files</title>
       <field line="1" label=" Index File " as-file="true" switch="~index_file=" />
       <field line="1" label=" Warning File " as-file="true" switch="~warning_file=" />
       <field line="1" label=" Configuration File " as-file="true" switch="~config=" />
-      <title line="2">Language</title>
-      <radio line="2" >
+      <title line="1" column="2" column-span="0" />
+      <title column="1" line="2">Language</title>
+      <radio column="1" line="2" >
         <radio-entry label="SPARK95" switch="~profile=sequential" />
         <radio-entry label="RavenSPARK" switch="~profile=ravenscar" />
         <radio-entry label="SPARK83" switch="~ada83" />
       </radio>
-      <title line="3">Analysis</title>
-      <radio line="3">
+      <title column="2" line="2">Analysis</title>
+      <radio column="2" line="2">
         <radio-entry label="Information and Data Flow" switch="~flow_analysis=information" />
         <radio-entry label="Data Flow only" switch="~flow_analysis=data" />
       </radio>
-      <check line="3" label="Generate Run Time Checks" switch="~exp_checks" />
-      <title line="4">Replacement rules for composite constants</title>
-      <radio line="4">
+      <check column="2" line="2" label="Generate Run Time Checks" switch="~exp_checks" />
+      <title line="3" line-span="2">Replacement rules for composite constants</title>
+      <radio line="3">
         <radio-entry label="None" switch="~rules=none" />
         <radio-entry label="Lazy" switch="~rules=lazy" />
 		<radio-entry label="Keen" switch="~rules=keen" />
         <radio-entry label="All" switch="~rules=all" />
       </radio>
-      <title line="5">Output</title>
-      <check line="5" label=" Plain Output " switch="~plain" />
-      <check line="5" label=" HTML Output " switch="~html" />
-      <field line="5" label=" Listing File Extension " switch="~listing=" />
-      <field line="5" label=" Report File Name " switch="~report=" />
-      <title line="6">Error Explanations</title>
-      <radio line="6">
+      <title column="2" line="3">Error Explanations</title>
+      <radio column="2" line="3">
         <radio-entry label="Off" switch="~error_explanations=off" />
         <radio-entry label="First Occurrence" switch="~error_explanations=first" />
 	<radio-entry label="Every Occurrence" switch="~error_explanations=every" />
       </radio>
-      <title line="7">General</title>
-      <field line="7" label=" Annotation Character " switch="~annotation_character=" tip="Enter a single character to follow '--' as the mark for SPARK annotations (default '#')" />
+      <title line="4" column="1" line-span="0" />
+      <title column="2" line="4">General</title>
+      <field column="2" line="4" label=" Annotation Character " switch="~annotation_character=" tip="Enter a single character to follow '--' as the mark for SPARK annotations (default '#')" />
+      <title line="5" column-span="2">Output</title>
+      <check line="5" label=" Plain Output " switch="~plain" />
+      <check line="5" label=" HTML Output " switch="~html" />
+      <field line="5" label=" Listing File Extension " switch="~listing=" />
+      <field line="5" label=" Report File Name " switch="~report=" />
+      <title line="5" column="2" column-span="0" />
     </switches>
   </tool>
 
@@ -207,6 +212,7 @@ a = """<?xml version="1.0"?>
       <check line="2" label="No Contradiction Hunt" switch="/nocontra" />
       <check line="2" label="No Substitution Elimination" switch="/nosubstitution" />
       <check line="2" label="No Rule Substitution" switch="/norule_substitution" />
+      <check line="2" label="No Expression Reduction" switch="/noexp" />
       <title line="3">Limits</title>
       <spin line="3" label="Memory Limit" switch="/memory_limit=" min="250000" max="30000000" default="9000000"
             tip="Max PROLOG Heap.  Default 9000000." />
@@ -274,7 +280,7 @@ a = """<?xml version="1.0"?>
   <!-- want to use metafiles or the simplifier, you'll also have  -->
   <!-- to select metafile and VCG as project languages.           -->
 
-  <action name="Examine file">
+  <action name="Examine file" category="Spark">
      <filter language="SPARK" />
      <filter language="Ada" />
      <shell>MDI.save_all false</shell>
@@ -285,7 +291,7 @@ a = """<?xml version="1.0"?>
      <shell>Locations.parse &quot;&quot;&quot;%1 &quot;&quot;&quot; Examiner</shell>
   </action>
 
-  <action name="SPARKFormat file">
+  <action name="SPARKFormat file" category="Spark">
      <filter language="SPARK" />
      <filter language="Ada" />
      <shell>MDI.save_all false</shell>
@@ -295,7 +301,7 @@ a = """<?xml version="1.0"?>
      <shell>Editor.edit %f 0 0 0 true</shell>
   </action>
 
-  <action name="Examine metafile">
+  <action name="Examine metafile" category="Spark">
      <filter language="Metafile" />
      <shell>MDI.save_all false</shell>
 	 <shell>Locations.remove_category Examiner</shell>
@@ -305,18 +311,18 @@ a = """<?xml version="1.0"?>
      <shell>Locations.parse &quot;&quot;&quot;%1 &quot;&quot;&quot; Examiner</shell>
   </action>
 
-  <action name="SPARK help" output="SPARK Help">
+  <action name="SPARK help" output="SPARK Help" category="Spark">
      <external>spark /help</external>
   </action>
 
-  <action name="Simplify file">
+  <action name="Simplify file" category="Spark">
     <filter language="VCG" />
     <shell>Project %p</shell>
     <shell>Project.get_tool_switches_as_string %1 "Simplifier" </shell>
     <external output="Simplifier Output">spadesimp %f %1</external>
   </action>
 
-  <action name="Simplify all">
+  <action name="Simplify all" category="Spark">
     <shell>Project %P</shell>
     <shell>Project.get_tool_switches_as_string %1 "Simplifier" </shell>
     <shell>Project %P</shell>
@@ -324,7 +330,7 @@ a = """<?xml version="1.0"?>
     <external output="SPARKSimp Output">sparksimp %1 ~sargs %3 </external>
   </action>
 
-  <action name="POGS">
+  <action name="POGS" category="Spark">
     <shell>MDI.save_all false</shell>
     <shell>cd %d</shell>
     <shell>Project %p</shell>
@@ -334,7 +340,7 @@ a = """<?xml version="1.0"?>
     <shell lang="python">GPS.Editor.edit(spark.pogs_file(), 0, 0, 0, -1)</shell>
   </action>
 
-  <action name="SPARKmake">
+  <action name="SPARKmake" category="Spark">
      <filter language="SPARK" />
      <filter language="Ada" />
      <shell>MDI.save_all false</shell>
